import { useState, useEffect } from "react";
import KeyboardArrowLeftIcon from "@mui/icons-material/KeyboardArrowLeft";
import KeyboardArrowRightIcon from "@mui/icons-material/KeyboardArrowRight";
import PauseRoundedIcon from '@mui/icons-material/PauseRounded';
import PlayArrowRoundedIcon from '@mui/icons-material/PlayArrowRounded';
import Image from "next/image";

const carouselItems = [
  {
    image: "/images/slide_1.png",
  },
  {
    image: "/images/slide_2.png",
  },
  {
    image: "/images/slide_3.png",
  },
  {
    image: "/images/slide_4.png",
  },
];

export const Carousel = () => {
  const [currentIndex, setCurrentIndex] = useState(0);
  const [paused, setPaused] = useState(false);

  useEffect(() => {
    if (!paused) {
      const interval = setInterval(() => {
        setCurrentIndex((prevIndex) => (prevIndex + 1) % carouselItems.length);
      }, 5000);

      return () => clearInterval(interval);
    }
  }, [paused, currentIndex]);


  return (
    <div className={`flex flex-col bg-transparent w-full my-3`}>

      <div className="relative w-[100%] aspect-[2/1] flex items-center overflow-hidden rounded-xl object-contain">
      <Image
        priority
        sizes="50vw"
        fill
        src={carouselItems[currentIndex].image}
        alt={`Imagem ${currentIndex + 1} do Carrossel`}
      />

        <button
          onClick={() =>
            setCurrentIndex(
              (prevIndex) =>
                (prevIndex - 1 + carouselItems.length) % carouselItems.length
            )
          }
          className="absolute left-0 top-[50%] -translate-y-[50%] text-white-HC-dark-underline" style={{ filter: "drop-shadow(0 4px 10px rgba(0, 0, 0, 1))" }}
        >
          <KeyboardArrowLeftIcon className="text-7xl max-sm:text-5xl "/>
        </button>
        <button
          onClick={() =>
            setCurrentIndex(
              (prevIndex) => (prevIndex + 1) % carouselItems.length
            )
          }
          className="absolute right-0 top-[50%] -translate-y-[50%] text-white-HC-dark-underline"  style={{ filter: "drop-shadow(0 4px 10px rgba(0, 0, 0, 1))" }}
        >
          <KeyboardArrowRightIcon className="text-7xl max-sm:text-5xl" />
        </button>
      </div>
      <div className="flex flex-row justify-between items-start">
        <div>
          {carouselItems.map((_, index) => (
            <button
              key={index}
              className={`rounded-full mx-1 w-[15px] h-[15px] ${index === currentIndex ? "bg-darkGray-HC-white" : "bg-ice-HC-dark-hover"
                } `}
              onClick={() => setCurrentIndex(index)}
            />
          ))}
        </div>
        <div className="text-darkGray-HC-white-underline text-[18px] font-medium">
          <button onClick={() => setPaused(!paused)} className="text-darkGray-HC-white-underline">
            {paused ? "Continuar" : "Parar"}
            {paused ? <PlayArrowRoundedIcon /> : <PauseRoundedIcon />} 
          </button>
        </div>
      </div>
    </div>
  );
};
