"use client"
import { useEffect, useState } from 'react';
import ContrastTwoToneIcon from '@mui/icons-material/ContrastTwoTone';
import { usePathname, useSearchParams } from 'next/navigation';
import { useRef, useLayoutEffect } from 'react';
import { useRouter } from 'next/navigation';
import { FaArrowCircleUp } from "react-icons/fa";
import { toggleContrast } from './themeUtils';
import { isLoggedIn } from "@/app/handlers/loginHandler";


export default function AcessibilityBar() {
    const sizes = ['xs', 'sm', 'base', 'lg', 'xl', '2xl', '3xl', '4xl', '5xl', '6xl', '7xl', '8xl', '9xl'];
    const [defaultSizes, setDefaultSizes] = useState({});
    const [sizeProperties, setSizeProperties] = useState({});
    const [loggedIn, setLoggedIn] = useState(false);

    const router = useRouter();
    const pathname = usePathname()

    function goHeader() {
        window.scrollTo({
            top: 0,
            behavior: "smooth"
        });
    }

    useEffect(() => {
      // Remove erro de hidratação forçando o cliente a usar localStorage e tirando isso do server
      setLoggedIn(isLoggedIn());
    }, [])

    function changeFont(action) {

        sizes.forEach(size => {
            sizeProperties[size].fontSize = parseInt(getComputedStyle(document.documentElement).getPropertyValue(`--font-size-${size}`).trim(), 10);
            sizeProperties[size].lineHeight = parseInt(getComputedStyle(document.documentElement).getPropertyValue(`--line-height-${size}`).trim(), 10);
        });

        switch (action) {
            case "increase":
                sizes.forEach(size => {
                    sizeProperties[size].fontSize += 2;
                    sizeProperties[size].fontSize = Math.min(sizeProperties[size].fontSize, sizeProperties[size].maxFontSize); // não passar do limite de tamanho da fonte

                    sizeProperties[size].lineHeight += 3;
                    sizeProperties[size].lineHeight = Math.min(sizeProperties[size].lineHeight, sizeProperties[size].maxLineHeight); // não passar do limite de tamanho da fonte
                })

                break;

            case "decrease":
                sizes.forEach(size => {
                    sizeProperties[size].fontSize -= 2;
                    sizeProperties[size].fontSize = Math.max(sizeProperties[size].fontSize, sizeProperties[size].minFontSize); // não passar do limite de tamanho da fonte

                    sizeProperties[size].lineHeight -= 3;
                    sizeProperties[size].lineHeight = Math.max(sizeProperties[size].lineHeight, sizeProperties[size].minLineHeight); // não passar do limite de tamanho da fonte
                })

                break;

            case "default":
            default:
                sizes.forEach(size => {
                    sizeProperties[size].fontSize = defaultSizes[size].fontSize;
                    sizeProperties[size].lineHeight = defaultSizes[size].lineHeight;
                })
        }

        sizes.forEach(size => {
            document.documentElement.style.setProperty(`--font-size-${size}`, `${sizeProperties[size].fontSize}px`);
            document.documentElement.style.setProperty(`--line-height-${size}`, `${sizeProperties[size].lineHeight}px`);
        });

    }

    useLayoutEffect(() => {
        document.getElementById('MECRED').tabIndex = "-1";

        try {
            document.getElementById('acessibilidade1').tabIndex = "1"; // coloca a barra de acessibilidade como a primeira coisa a ser acessada pelo TAB
        }
        catch (e) { }

        sizes.forEach(size => {
            defaultSizes[size] = {
                fontSize: null,
                lineHeight: null
            }
        });

        sizes.forEach(size => {
            defaultSizes[size].fontSize = parseInt(getComputedStyle(document.documentElement).getPropertyValue(`--font-size-${size}-default`).trim(), 10);
            defaultSizes[size].lineHeight = parseInt(getComputedStyle(document.documentElement).getPropertyValue(`--line-height-${size}-default`).trim(), 10);
        });

        sizes.forEach(size => {
            sizeProperties[size] = {
                fontSize: 42,
                lineHeight: 42,

                minFontSize: parseInt(getComputedStyle(document.documentElement).getPropertyValue(`--font-size-${size}-min`).trim(), 10),
                minLineHeight: parseInt(getComputedStyle(document.documentElement).getPropertyValue(`--line-height-${size}-min`).trim(), 10),
                maxFontSize: parseInt(getComputedStyle(document.documentElement).getPropertyValue(`--font-size-${size}-max`).trim(), 10),
                maxLineHeight: parseInt(getComputedStyle(document.documentElement).getPropertyValue(`--line-height-${size}-max`).trim(), 10),
            };
        });


        setDefaultSizes(defaultSizes);
        setSizeProperties(sizeProperties);

    }, [])

    const handleAccessibility = (buttonNumber) => {

        let elementId;


        switch (buttonNumber) {
            case 1:
                elementId = 'conteudo';
                break;
            case 2:
                elementId = 'MEC';
                break;
            case 3:
                elementId = 'buscar';
                break;
            default:
                elementId = '';
        }

        try {
            let focusElement = document.getElementById(elementId);
            if (focusElement) {
                focusElement.focus();
            }
        }
        catch (erro) { }
    };

    return (
        <>
            <div className="block xl:hidden">
                <div className="fixed top-0 flex justify-between w-screen bg-white-HC-dark  z-20 text-[12px] py-1 px-3 text-darkGray-HC-white whitespace-nowrap border-b border-ice-HC-white">

                    <div className="flex w-full leading-tight">

                        <button onClick={() => toggleContrast()}>
                            <ContrastTwoToneIcon className="text-3xl pb-1" />
                        </button>

                        <h1 className="mt-1 font-light text-start" id="MECRED">
                            MEC RED - A Rede Social da Educação
                        </h1>
                    </div>
                    <button onClick={goHeader}><FaArrowCircleUp className='text-2xl' /></button>
                </div>
            </div>

            <div className="hidden xl:block">
                {pathname !== "/entrar" ? (
                    <>
                        <div className="fixed top-0 flex justify-between w-screen bg-white-HC-dark  z-20 text-[12px] leading-[20px] py-1 px-6 text-darkGray-HC-white whitespace-nowrap border-b border-ice-HC-white">

                            <div className="flex justify-between w-full max-sm:hidden">

                                <h1 className="mt-1 font-light text-start" id="MECRED">
                                    MEC RED - A Rede Social da Educação
                                </h1>

                                <button className='font-light' id="acessibilidade1" onClick={() => handleAccessibility(1)}>
                                    1- Ir para o conteúdo.
                                </button>

                                <button className='font-light' onClick={() => handleAccessibility(2)}>
                                    2- Ir para o menu.
                                </button>

                                <button className='font-light' onClick={() => handleAccessibility(3)}>
                                    3- Ir para a busca.
                                </button>

                                {!loggedIn &&
                                    <button className='font-light' onClick={() => router.push("/entrar")}>
                                        4- Ir para login.
                                    </button>
                                }

                                <div className="font-light flex py-1">
                                    <button>Tamanho do texto:&nbsp;&nbsp;&nbsp;&nbsp;</button>
                                    <button onClick={() => changeFont("decrease")}>A-</button>
                                    &nbsp;&nbsp;&nbsp;&nbsp;
                                    <button onClick={() => changeFont("default")}>A</button>
                                    &nbsp;&nbsp;&nbsp;&nbsp;
                                    <button onClick={() => changeFont("increase")}>A+</button>
                                </div>

                                <button className='font-light' onClick={() => toggleContrast()}>
                                    Alto Contraste <ContrastTwoToneIcon
                                        className="text-m font-light pb-1" />
                                </button>

                                <button className='font-light' onClick={() => router.push("/acessibilidade")}>
                                    Acessibilidade
                                </button>

                                {/*<button onClick={() => window.scrollTo({ top: 0, behavior: 'smooth' })}>
                                    Mapa do Site
                                </button> */}

                            </div>
                        </div>
                    </>
                ) :
                    (
                        <>
                            <div className="fixed top-0 flex justify-between w-screen bg-white-HC-dark  z-20 text-[14px] py-1 px-3 text-darkGray-HC-white whitespace-nowrap border-b border-ice-HC-white">

                                <div className="flex justify-between w-full leading-tight">
                                    <h1 className="mt-1 font-light text-start" id="MECRED">
                                        MEC RED - A Rede Social da Educação
                                    </h1>

                                    <button className='font-light' id="acessibilidade1" onClick={() => handleAccessibility(1)}>
                                        1- Ir para o conteúdo.
                                    </button>

                                    {!loggedIn &&
                                        <button className='font-light' onClick={() => router.push("/entrar")}>
                                            2- Ir para login.
                                        </button>
                                    }
                                    <div className="flex font-light items-center space-x-10">
                                        <div className="flex">
                                            <button>Tamanho do texto:&nbsp;&nbsp;&nbsp;&nbsp;</button>
                                            <button className='font-light' onClick={() => changeFont("decrease")}>A-</button>
                                            &nbsp;&nbsp;&nbsp;&nbsp;
                                            <button className='font-light' onClick={() => changeFont("default")}>A</button>
                                            &nbsp;&nbsp;&nbsp;&nbsp;
                                            <button className='font-light' onClick={() => changeFont("increase")}>A+</button>
                                        </div>

                                        <button className='font-light' onClick={() => toggleContrast()}>
                                            Alto Contraste <ContrastTwoToneIcon
                                                className="text-m pb-1" />
                                        </button>

                                        <button className='font-light' onClick={() => router.push("/acessibilidade")}>
                                            Acessibilidade
                                        </button>

                                    </div>
                                </div>
                            </div>
                        </>
                    )}
            </div>
        </>
    );

}
