import { useState } from "react";
import KeyboardArrowLeftIcon from "@mui/icons-material/KeyboardArrowLeft";
import KeyboardArrowRightIcon from "@mui/icons-material/KeyboardArrowRight";
import Image from "next/image";

const carouselItems = [
  {
    image: "/images/prof.png",
    description: "Encontre recursos digitais que atendem aos objetivos das suas aulas! Aproveite para seguir outros professores, acessar coleções e conhecer novas experiências de uso!"
  },
  {
    image: "/images/aluno.png",
    description: "Você pode complementar seus estudos com recursos digitais que lhe interessem. Gostou de algum recurso? Recomende-o ao seu professor ou professora.",
  },
  {
    image: "/images/gest.png",
    description: "Desenvolva, junto com o coletivo da escola, ações e projetos pedagógicos utilizando recursos digitais importantes para o seu contexto."
  },
  {
    image: "/images/com_acad.png",
    description: "Encontre recursos digitais e materiais de formação que contribuam para a aprendizagem e para práticas educativas na comunidade escolar."
  },
];

export const ActorsCarousel = () => {
  const [currentIndex, setCurrentIndex] = useState(0);

  return (
    <div className={`flex flex-col bg-transparent w-full my-3 items-center`}>
        <h1 className="text-xl text-darkGray-HC-white-underline font-bold mb-3 mt-5">
          O que você pode fazer aqui?
        </h1>
      <div className="relative aspect-[3/2] flex items-center overflow-hidden rounded-xl object-contain">
        <Image
          priority
          width={500}
          height={100}
          src={carouselItems[currentIndex].image}
          alt={`Imagem ${currentIndex + 1} do Carrossel`}
        />
        <button
          onClick={() =>
            setCurrentIndex(
              (prevIndex) =>
                (prevIndex - 1 + carouselItems.length) % carouselItems.length
            )
          }
          className="absolute left-0 top-[50%] -translate-y-[50%] text-white-HC-dark-underline" style={{ filter: "drop-shadow(0 4px 10px rgba(0, 0, 0, 1))" }}
        >
          <KeyboardArrowLeftIcon className="text-7xl max-sm:text-5xl " />
        </button>
        <button
          onClick={() =>
            setCurrentIndex(
              (prevIndex) => (prevIndex + 1) % carouselItems.length
            )
          }
          className="absolute right-0 top-[50%] -translate-y-[50%] text-white-HC-dark-underline" style={{ filter: "drop-shadow(0 4px 10px rgba(0, 0, 0, 1))" }}
        >
          <KeyboardArrowRightIcon className="text-7xl max-sm:text-5xl " />
        </button>
      </div>
      <div className="flex flex-row justify-center gap-1 items-center py-4">
        {carouselItems.map((_, index) => (
          <button
            key={index}
            className={`rounded-full w-[10px] h-[10px] ${index === currentIndex ? "bg-darkGray-HC-white" : "bg-ice-HC-dark-hover"
              } `}
            onClick={() => setCurrentIndex(index)}
          />
        ))}
      </div>
      <p className="text-light text-darkGray-HC-white-underline mt-4 text-base text-center">
        {carouselItems[currentIndex].description}
      </p>
    </div>
  );
};

