import { useState } from "react";
import { motion } from "framer-motion";
import Image from "next/image";
import KeyboardArrowLeftIcon from "@mui/icons-material/KeyboardArrowLeft";
import KeyboardArrowRightIcon from "@mui/icons-material/KeyboardArrowRight";
import { useSwipeable } from "react-swipeable";

let images = [
  {
    image: "/pesquisa.svg",
    color: "#00bacc",
    description: "São mais de 20 mil recursos educacionais à sua disposição, provenientes de portais parceiros do MEC e de professores que, como você, atuam na Educação Básica!",
  },
  {
    image: "/colecionar.svg",
    color: "#56358c",
    description: "Guarde e organize em coleções os recursos que você considera interessantes para elaborar a sua aula. Aproveite para indicá-los aos colegas pelas redes sociais ou e-mail.",
  },
  {
    image: "/compartilhar.svg",
    color: "#ed6f24",
    description: "Você pode relatar suas experiências sobre o uso de recursos no seu cotidiano escolar. Aproveite esse espaço para sugerir e conhecer novos usos para um mesmo recurso.",
  },
  {
    image: "/download.svg",
    color: "#e62954",
    description: "Colabore e ajude a fortalecer a MEC RED publicando um recurso educacional desenvolvido por você ou pelo coletivo da escola do qual faz parte. Compartilhe seu conhecimento e dê visibilidade ao seu recurso, tornando-o público e eriquecendo o conhecimento partilhado!",
  },
  {
    image: "/verificado.svg",
    color: "#ed6f24",
    description: "A MEC RED disponibiliza um conjunto de materiais de formação recomendados pelo Ministério da Educação com diversidade de temas e recursos educacionais.",
  }
]

export const FunctionalitiesCarousel = () => {
  const [positionIndexes, setPositionIndexes] = useState([0, 1, 2, 3, 4]);
  const [actualDescription, setActualDescription] = useState(0);

  const handleNext = () => {
    setPositionIndexes((prevIndexes) => {
      const updatedIndexes = prevIndexes.map(
        (prevIndex) => (prevIndex + 1) % 5
      );
      setActualDescription((actualDescription + 1) % 5);
      return updatedIndexes;
    });
  };

  const handleBack = () => {
    setPositionIndexes((prevIndexes) => {
      const updatedIndexes = prevIndexes.map(
        (prevIndex) => (prevIndex + 4) % 5
      );
      setActualDescription((actualDescription + 4) % 5);
      return updatedIndexes;
    });
  };

  const handleClick = (position) => {
    if (position === "left" || position === "left1") {
      handleBack();
    } else if (position === "right" || position === "right1") {
      handleNext();
    }
  };

  const positions = ["center", "left1", "left", "right", "right1"];

  const imageVariants = {
    center: { x: "0%", scale: 1, zIndex: 5 },
    left1: { x: "-50%", scale: 0.7, zIndex: 3 },
    left: { x: "-90%", scale: 0.5, zIndex: 2 },
    right: { x: "90%", scale: 0.5, zIndex: 1 },
    right1: { x: "50%", scale: 0.7, zIndex: 3 },
  };

  const swipeHandlers = useSwipeable({
    onSwipedLeft: handleNext,
    onSwipedRight: handleBack,
    preventDefaultTouchmoveEvent: true,
  });

  return (
    <div className="flex flex-col justify-center items-center m-4" {...swipeHandlers}>
       <h1 className="text-xl text-darkGray-HC-white-underline font-bold mb-3 mt-5">
          Como você pode participar?
        </h1>
      <div className="flex flex-col gap-16">
        <div className="flex justify-center items-center flex-row gap-60 mt-16">
          <button
            className="text-white-HC-dark-underline bg-lightGray-HC-white  rounded-full"
            onClick={handleBack}
          >
            <KeyboardArrowLeftIcon className="text-2sm" />
          </button>
          {images.map((image, index) => (
            <motion.div
              key={index}
              className={`flex h-24 w-24 my-2 mx-10 rounded-full items-center justify-center ${image.color}`}
              initial="center"
              animate={positions[positionIndexes[index]]}
              variants={imageVariants}
              transition={{ duration: 0.5 }}
              style={{ width: "20%", position: "absolute", cursor: "pointer", background: image.color }}
              onClick={() => handleClick(positions[positionIndexes[index]])}
            >
              <Image
                style={{ filter: "invert(100%)" }}
                src={image.image}
                alt={image.image}
                width={50}
                height={50}
                className={`rounded-lg w-14 h-14`}
              />
            </motion.div>
          ))}
          <button
            className="text-white-HC-dark-underline bg-lightGray-HC-white  rounded-full"
            onClick={handleNext}
          >
            <KeyboardArrowRightIcon className="text-2sm" />
          </button>
        </div>
        <div className="flex items-center text-darkGray-HC-white-underline text-light text-base">
          {images[actualDescription].description}
        </div>
      </div>
      <div className="flex flex-row gap-3"></div>
    </div>
  );
};
