"use client";

import React, { useEffect, useState } from "react";
import Link from "next/link";
import CloseIcon from "@mui/icons-material/Close";
import IconButton from "@mui/material/IconButton";
import MenuIcon from "@mui/icons-material/Menu";
import SearchIcon from "@mui/icons-material/Search";
import AccountMenu from "./MenuProfile";
import SearchComponent from "./SearchComponent";
import NeedLoginModal from "./needLoginModal";
import { isLoggedIn, useLoginBarrier } from "@/app/handlers/loginHandler";
import { usePathname } from "next/navigation";
import { useRouter } from "next/navigation";
import { ImArrowLeft } from "react-icons/im";
import Notifications from "./Notifications";
import { toggleContrast } from './themeUtils';
import ContrastTwoToneIcon from '@mui/icons-material/ContrastTwoTone';

function DefaultContent({
  handleToggleMobileSearch,
  setNeedLoginOpen,
  setFilterState,
  filterState
}) {
  const pathname = usePathname();
  const router = useRouter();
  const loginBarrier = useLoginBarrier();
  const [loggedIn, setLoggedIn] = useState(false);

  useEffect(() => {
    setLoggedIn(isLoggedIn());
  }, [])

  const handleOpenSubmit = () => {
    if (!isLoggedIn()) {
      setNeedLoginOpen(true);
    } else {
      const params = new URLSearchParams();
      params.set("redirect", pathname);
      router.push(`/publicar`);
    }
  };

  return (
    <>
      <div className="grid xl:grid-cols-[150px_auto_500px] md:grid-cols-[150px_auto_300px] grid-cols-[170px_auto] max-md:pl-8 w-full">
        <Link href="/" className="flex justify-center items-center">
          <div className="flex gap-2 justify-center items-center">
            {/* <div
              className="w-[59px] h-[50px] bg-no-repeat bg-center bg-contain bg-logo-square"        
              aria-label="logo"
            /> */}
            <img
              className="w-[59px] h-[50px] bg-no-repeat bg-center bg-contain bg-logo-square invertLogo-HC-white"              
              src={"/mecred_square.svg"}
              alt="MECRED logo"              
            />
            <div className="md:hidden text-darkGray-HC-white text-sm font-light w-full">
              A Rede Social da Educação
            </div>
          </div>

        </Link>
        <div className="grow hidden md:flex items-center">
          <SearchComponent setFilterState={setFilterState} filterState={filterState} />
        </div>
        <div className="flex justify-start shrink-0 grow-0 items-center px-[25px]">
          <div className="flex items-center max-md:hidden gap-6">
            <button
              type="button"
              alt="Abrir busca"
              title="Abrir busca"
              className="md:hidden bg-turquoise hover:bg-darkGray-HC-white w-10 h-10 rounded text-white-HC-dark-underline shrink-0 transition"
              onClick={handleToggleMobileSearch}
            >
              <SearchIcon className="h-full text-3xl" />
            </button>

            <button
              type="button"
              className="group bg-lightGray-HC-dark max-sm:hidden hover:bg-darkGray-HC-white h-[50px] px-4 rounded-lg text-lg text-darkGray-HC-white-underline hover:text-white-HC-dark-underline flex items-center font-bold flex-shrink-0 outline outline-1 outline-ice-HC-white"
              onClick={handleOpenSubmit}
            >
              <ImArrowLeft
                className="rotate-90 group-hover:-rotate-180 transition max-md:mr-3 max-xl:mr-0 mr-3 mb-0.5 text-2xl"
              />
              <div className="max-xl:hidden max-md:flex ">Publicar recurso</div>
            </button>
          </div>

          <div className="flex grow justify-end items-center max-md:ml-10">
            <button onClick={() => toggleContrast()}>
               <ContrastTwoToneIcon
               className=" text-darkGray-HC-white md:hidden w-[25px] h-[25px]"/>
            </button>
            {loggedIn ? (
              <>
                <Notifications />

                <div className="max-md:hidden"><AccountMenu  /></div>
              </>
            ) : (
              <button
                type="button"
                className="group bg-orange-HC-white hover:bg-darkOrange-HC-dark px-4 h-10 mr-8 max-sm:ml-2 rounded text-white-HC-dark-underline flex items-center font-bold flex-shrink-0 hover:text-white-HC-underline outline outline-1 outline-ice-HC-white"
                onClick={loginBarrier}
              >
                Entrar
              </button>
            )}

          </div>
        </div>
      </div>
    </>
  );
}

export function MobileSearch({ setFilterState, filterState, handleToggleMobileSearch }) {
  return (
    <div className="flex w-full items-center">
      <SearchComponent setFilterState={setFilterState} filterState={filterState} />
      <button
        type="button"
        alt="Fechar busca"
        title="Fechar busca"
        className={"bg-darkGray-HC-white w-10 h-10 mr-2 rounded text-white-HC-dark-underline shrink-0  transition-all duration-30000 hover:bg-turquoise-HC-dark"}
        onClick={handleToggleMobileSearch}
      >
        <CloseIcon className="h-full text-3xl " />
      </button>
    </div>
  );
}

/**
  * @param {Object} props
  * @param {Function} props.setQuery - seta o query
  * @returns header
  */
export default function Header({ setFilterState, filterState, mobileSearch }) {
  const [needLoginOpen, setNeedLoginOpen] = useState(false);
  const [mobileSearchOpen, setMobileSearchOpen] = useState(false);

  // Função para alternar a exibição da pesquisa no mobile
  const handleToggleMobileSearch = () => {
    setTimeout(() => {
      setMobileSearchOpen((curr) => !curr);
    }, 100);
  };

  return (
    <div className="fixed flex items-center max-md:h-[70px] h-[120px] top-[35px] max-md:top-[0px] z-20 shadow-none w-screen bg-fundo bg-repeat bg-fixed">
      <div className="flex flex-grow gap-3 sm:gap-12 justify-between ">
        {mobileSearchOpen || mobileSearch.searchIsClicked ? (
          <MobileSearch handleToggleMobileSearch={handleToggleMobileSearch} setFilterState={setFilterState} filterState={filterState} />
        ) : (
          <DefaultContent
            handleToggleMobileSearch={handleToggleMobileSearch}
            setNeedLoginOpen={setNeedLoginOpen}
            setFilterState={setFilterState}
            filterState={filterState}
          />
        )}
      </div>
      <NeedLoginModal open={needLoginOpen} setOpen={setNeedLoginOpen} />
    </div>
  );
}
