import { mecredURL } from "@/axiosConfig";
import Image from "next/image";
import { useRouter } from "next/navigation";


const timeFunction = (updated_time) => {
    let data = new Date(updated_time)
    let dataAtual = new Date();
    let time = dataAtual.getTime() - data.getTime();
    let dia = Math.floor(time / (1000 * 60 * 60 * 24));
    let ano;
    let mes;

    if ((ano = Math.floor(dia / 365)) > 0)
        return <span className="text-xs	"> há {ano} {ano === 1 ? "ano" : "anos"} </span>
    else if (((mes = Math.floor(dia / 31)) > 0))
        return <span className="text-xs	"> há {mes} {mes === 1 ? "mês" : "meses"}</span>

    if (dia === 0)
        return <span className="text-xs	"> hoje</span>
    return <span className="text-xs	"> há {dia} {dia === 1 ? "dia" : "dias"}</span>
}

function getRandomBg(id) {
    const colors = [
        "bg-turquoise-HC-white",
        "bg-orange-HC-white",
        "bg-darkTurquoise-HC-white",
        "bg-darkOrange-HC-white",
        "bg-violet-HC-white",
        "bg-pink-HC-white",
        "bg-red-HC-white",
        "bg-darkGray-HC-white",
        "bg-ice-HC-white",
    ]

    return colors[id % colors.length];
}

function tradutor(nome) {
    switch (nome) {
        case "like.create":
            return "curtiu"
        case "like.destroy":
            return "descurtiu"
        case "download.create":
            return "baixou"
        case "review.create":
            return "avaliou"
        case "curator_assignment.create":
            return "você foi atribuido para avaliar "
        case "submission.rejected":
            return "sua submissão foi rejeitada pela equipe de avaliadores."
        case "submission.accepted":
            return "sua submissão foi aceita pela equipe de avaliadores: "
            
        default:
            return nome;
    }
}


export default function ItemNotification({ notification, postViewNotification }) {
    const router = useRouter();

    
    const viewOneNotification = () => {
        const payload = {
            "activities": {
                "ids": [notification.id]
            }
        }
    
 
        postViewNotification(payload)
        router.push(`recurso/${notification.recipient?.id}`)

    }

    return (
        <div className="flex flex-row px-3 py-4 mt-1 ml-2 hover:bg-ice-HC-dark  hover:rounded-lg" onClick={viewOneNotification}  >
            <div className="pr-3 pl-1 shrink-0 flex items-center">
                {!notification.owner?.avatar ? <div className={`flex items-center justify-center text-xl font-bold  text-ice-HC-dark rounded-full h-[43px] w-[43px] ${getRandomBg(notification.owner.id)}`} >{notification.owner.name[0]}</div>
                    :
                    <Image
                        src={mecredURL + notification.owner.avatar}
                        alt={notification.owner.name}
                        width={43}
                        height={43}
                        className="w-[43px] h-[43px] object-cover rounded-full"
                    />
                }
            </div>
            <div>
                <p className="text-sm font-bold text-darkGray-HC-white line-clamp-1">

                    {notification.owner.name}
                </p>
                <p className="text-sm font-normal text-darkGray-HC-white line-clamp-2 ">
                    {tradutor(notification.activity)}
                    <a className="text-turquoise-HC-underline -hover" href={`recurso/${notification.recipient?.id}`} >
                        {notification.recipient?.name}
                    </a>
                </p>
                <p className="text-sm font-light text-darkGray-HC-white ">
                    {timeFunction(notification.created_at)}
                </p>
            </div>
        </div>
    )
}