import Button from '@mui/material/Button';
import Menu from '@mui/material/Menu';
import MenuItem from '@mui/material/MenuItem';
import NotificationsIcon from "@mui/icons-material/Notifications";
import { Badge, Divider } from "@mui/material";
import { useEffect, useState } from 'react'
import Image from 'next/image';
import Loading from './Loading';
import ItemNotification from './ItemNotification';





export default function ModalNotifications({ countNotifications, notifications, postViewNotification }) {

    const [anchorEl, setAnchorEl] = useState(null);
    const open = Boolean(anchorEl);
    const handleClick = (event) => {
        setAnchorEl(event.currentTarget);
    };
    const handleClose = () => {
        setAnchorEl(null);
    };

    const setViewdAllNotification = () => {
        const payload = {
            "activities": {
                "ids": []
            }
        }

        notifications.forEach((noti) => payload.activities.ids.push(noti.id));
        
        postViewNotification(payload)
    }

    return (
        <div>
            <Button
                type="button"
                alt="Notificações"
                title="Em construção"
                className="bg-transparent max-sm:-ml-px max-sm:-mr-2 hover:text-turquoise-HC-white-underline w-10 h-10 rounded text-darkGray-HC-white flex-shrink-0 transition"
                id="basic-button"
                aria-controls={open ? 'basic-menu' : undefined}
                aria-haspopup="true"
                aria-expanded={open ? 'true' : undefined}
                onClick={handleClick}
            >
                <Badge badgeContent={countNotifications} 
                    
                    sx={{
                        '& .MuiBadge-badge': {
                            backgroundColor: 'var(--turquoise-HC-white)',
                            color: 'var(--ice-HC-dark)'
                        }
                    }}
                    >
                    <NotificationsIcon className="h-full text-3xl" />
                </Badge>

            </Button>
            <Menu
                id="basic-menu"
                anchorEl={anchorEl}
                open={open}
                onClose={handleClose}
                sx={{ 
                    top: 20,
                    backgroundColor: 'transparent',
                    '& .MuiPaper-root': {
                        backgroundColor: 'var(--ice-HC-dark)',
                        border: '2px solid var(--ice-HC-white)',
                        borderRadius: '8px',
                    }
                }}
                transformOrigin={{ horizontal: "right", vertical: "top" }}
                anchorOrigin={{ horizontal: "right", vertical: "bottom" }}
            >
                <div className='flex pr-2'  >
                    <div className='text-lg py-3 font-bold text-darkGray-HC-white pl-6 pr-16'> Notificações </div>
                    <button className='text-darkGray-HC-white-underline text-sm bg-mediumGray-HC-dark rounded-xl px-2 h-10 mt-1 mr-1 hover:bg-mediumGray-HC-white hover:text-darkGray-HC-dark-underline outline outline-1 outline-ice-HC-white' onClick={setViewdAllNotification}> Marcar como lidas </button>
                </div>t 
                <div className='px-4'>
                    <hr className='border-mediumGray-HC-white' />
                </div>
                <div className='w-80 h-80' >

                    {countNotifications ?
                        (notifications?.map((notification, index) => {
                            return (
                                <div key={index} className='pl-2' >
                                    <ItemNotification notification={notification} postViewNotification={postViewNotification} />
                                    <div className='pl-4'>
                                        <hr className="border-turquoise-HC-white h-1 my-2 "/>
                                    </div>

                                </div>
                            )
                        }))
                        :
                        (
                            countNotifications === 0 ?
                                <p className='text-darkGray-HC-white text-center pt-[40%]'> Não há notificações não lidas</p>
                                :
                                <Loading />
                        )
                    }

                </div>
            </Menu>
        </div>
    );
}
