"use client";
import { Card } from "@mui/material";
import { useState } from "react";
import Overlay from "../components/Overlay";
import { Button, Modal } from "@mui/material";
import mecredApi from "@/axiosConfig";

export default function Contact() {
  const [errorMessage, setErrorMessage] = useState("");
  const [successOpen, setSuccessOpen] = useState(false);

  function verifyForm(formData) {
    if (
      formData.get("name") === "" ||
      formData.get("email") === "" ||
      formData.get("contents") === ""
    ) {
      return false;
    }
    return true;
  }

  const sendMessage = async (event) => {
    event.preventDefault();

    const formData = new FormData(event.target);

    if (!verifyForm(formData)) {
      alert("Por favor, preencha todos os campos.");
      return;
    }

    await mecredApi
      .post("/contacts", {
        name: formData.get("name"),
        email: formData.get("email"),
        message: formData.get("contents"),
      })
      .then((response) => {
        setSuccessOpen(true);
      })
      .catch((error) => {
        setErrorMessage(error?.response?.data?.errors[0]);
      });
  };

  const ModalSucess = ({ open, onClose }) => {
    return (
      <Modal open={open} onClose={onClose} className="grid place-items-center"
        slotProps={{
          backdrop: {
            sx: {
              backgroundColor: "rgba(0, 0, 0, 0.3)", // Ajuste a opacidade conforme necessário
            },
          },
        }}>
        <div className="flex flex-col justify-center bg-ice-HC-dark p-5 rounded">
          <p className="text-xl justify-center flex text-darkGray-HC-white-underline mb-2">
            Mensagem enviada com sucesso!
          </p>
          <div className="flex flex-row mt-2 justify-center gap-3">
            <button
              className="text-sm text-darkGray-HC-white-underline border-main rounded-lg normal-case font-bold bg-ice-HC-dark hover:bg-ice-HC-dark-hover"
              onClick={() => onClose()}
            >
              OK
            </button>
          </div>
        </div>
      </Modal>
    );
  };

  return (
    <Overlay>
      <ModalSucess
        open={successOpen}
        onClose={() => {
          setSuccessOpen(false);
        }}
      />
      <div className="flex justify-center overflow-y-auto max-md:mx-8 max-md:mb-24 outline outline-1 outline-ice-HC-white">
        <Card
          className="flex w-full h-full min-h-[700px] text-darkGray-HC-white bg-white-HC-dark  outline outline-1 outline-ice-HC-white"
          sx={{
            display: "flex",
            flexDirection: "column",
            alignItems: "center",
            boxShadow: "none",
            padding: "20px",
          }}
        >
          <form
            onSubmit={sendMessage}
            className="mb-5 flex w-full max-w-2xl"
          >
            <div className="flex flex-col justify-center text-center items-center gap-8 mt-8 w-full">
              <p className="text-2xl font-bold">Contato</p>
              <p className="text-xl font-light text-center">
                Entre em contato para enviar dúvidas, sugestões ou críticas.
              </p>
              <div className="w-full">
                <p className="text-darkGray-HC-white text-left text-sm">Nome*</p>
                <input
                  className="w-full h-12 border-text-darkGray-HC-white-underline border rounded text-darkGray-HC-white-underline pl-2 bg-transparent focus:outline-none focus:border-input-focus"
                  type="text"
                  name="name"
                  required
                />
              </div>
              <div className="w-full">
                <p className="text-darkGray-HC-white text-left text-sm">E-mail*</p>
                <input
                  className="w-full h-12 border-text-darkGray-HC-white-underline border rounded text-darkGray-HC-white-underline pl-2 bg-transparent focus:outline-none focus:border-input-focus"
                  type="email"
                  name="email"
                  required
                />
              </div>
              <div className="w-full">
                <p className="text-darkGray-HC-white text-left text-sm">Mensagem*</p>
                <textarea
                  className="w-full h-36 border-text-darkGray-HC-white-underline border rounded text-darkGray-HC-white-underline p-2 bg-transparent focus:outline-none focus:border-input-focus"
                  name="contents"
                  required
                ></textarea>
              </div>
              <Button
                className="border-turquoise-HC-white hover:border-darkTurquoise-HC-white hover:bg-darkTurquoise-HC-dark bg-turquoise-HC-white hover:bg-ice-HC-dark-hover text-white-HC-dark-underline hover:text-white-HC-underline normal-case font-bold w-full text-lg"
                type="submit"
                variant="outlined"
                alt="Enviar mensagem"
                title="Enviar mensagem"
              >
                Enviar mensagem
              </Button>
              <p className="text-xs font-light">
                Os campos marcados com * são obrigatórios.
              </p>
            </div>
          </form>
        </Card>
      </div>
    </Overlay>
  );
}
