"use client";
import Image from "next/image";
import {
  Button,
  Paper,
  TextField,
  Alert,
  InputAdornment,
  IconButton,
  OutlinedInput,
  InputLabel,
  FormControl,
} from "@mui/material";
import theme from "@/app/theme";
import { ThemeProvider } from "@emotion/react";
import { useState } from "react";
import SignupModal from "./SignupModal";
import PasswordModal from "./PasswordModal";
import Title from "@/app/components/Title";
import { useRouter } from "next/navigation";


export default function LoginForm({
  handleEmailChange,
  handlePasswordChange,
  handleSubmit,
  errorMessage,
  uppercase,
}) {
  const [openModalSignup, setOpenModalSignup] = useState(false);
  const [openModalPasswd, setOpenModalPasswd] = useState(false);
  const [showPassword, setShowPassword] = useState(false);

  const handleOpenModalSignup = () => setOpenModalSignup(true);
  const handleCloseModalSignup = () => setOpenModalSignup(false);
  const handleOpenModalPasswd = () => setOpenModalPasswd(true);
  const handleCloseModalPasswd = () => setOpenModalPasswd(false);

  const handleClickShowPassword = () => setShowPassword((show) => !show);

  const router = useRouter();

  return (
    <ThemeProvider theme={theme}>
      <div className="xl:fixed">
        <div className="flex xl:ml-[35%] xl:my-[30%] items-center flex-col-reverse mt-20">
          <div className="xl:hidden">
            <Title />
          </div>
          <div className="flex flex-col ">
            <form onSubmit={handleSubmit} className="mb-5">
              <Paper elevation={0} className="flex flex-col bg-white-HC-dark w-96 items-center p-5 rounded-xl outline outline-1 outline-ice-HC-white">
                <Image
                  src="/mecred.svg"
                  alt="MECRED Logo"
                  width={100}
                  height={24}
                  className="m-5 invertLogo-HC-white"
                />
                {errorMessage ? (
                  <Alert severity="error" className="mb-3">{errorMessage}</Alert>
                ) : null}

                {/* Campo de E-mail */}
                <div className="w-full mb-6">
                  <label htmlFor="email" className="block text-sm font-light text-darkGray-HC-white mb-1">
                    Insira seu e-mail
                  </label>
                  <input
                    id="email"
                    type="email"
                    className="w-full px-3 py-2 border border-mediumGray-HC-white rounded-md focus:outline-none focus:ring-2 focus:ring-turquoise-HC-white"
                    onChange={handleEmailChange}
                    alt="E-mail"
                  />
                </div>

                {/* Campo de Senha */}
                <div className="w-full mb-6">
                  <label htmlFor="password" className="block text-sm font-light text-darkGray-HC-white mb-1">
                    Insira sua senha
                  </label>
                  <div className="relative">
                    <input
                      id="password"
                      type={showPassword ? 'text' : 'password'}
                      className="w-full px-3 py-2 border border-mediumGray-HC-white rounded-md focus:outline-none focus:ring-2 focus:ring-turquoise-HC-white"
                      onChange={handlePasswordChange}
                      alt="Senha"
                    />
                    <button
                      type="button"
                      onClick={handleClickShowPassword}
                      className="absolute inset-y-0 right-0 pr-3 flex items-center text-sm leading-5"
                    >
                      {showPassword ? <img src="ocultar-senha.svg" alt="Ocultar senha" /> : <img src="ver-senha.svg" alt="Ver senha" />}
                    </button>
                  </div>
                </div>

                {/* Botão de Entrar */}
                <Button
                  fullWidth
                  disableElevation
                  className="bg-turquoise-HC-white text-white-HC-dark-underline hover:bg-darkTurquoise-HC-dark hover:text-white normal-case font-bold py-2 rounded-md outline outline-1 outline-ice-HC-white"
                  type="submit"
                  alt="Entrar"
                  title="Entrar"
                >
                  Entrar
                </Button>

                {/* Links de Recuperação de Senha e Cadastro */}
                <p className="mt-5 text-[14px] text-darkGray-HC-white">
                  Esqueceu a senha?{" "}
                  <a
                    onClick={handleOpenModalPasswd}
                    className="text-turquoise-HC-white-underline  cursor-pointer hover:font-bold"
                    alt="Esqueceu a senha?"
                  >
                    Clique aqui.
                  </a>
                </p>
                <p className="mt-2 text-[16px] text-darkGray-HC-white">
                  Não tem uma conta?{" "}
                  <a
                    onClick={handleOpenModalSignup}
                    className="text-turquoise-HC-white-underline  hover:font-bold cursor-pointer"
                    alt="Cadastre-se"
                  >
                    Cadastre-se aqui.
                  </a>
                </p>

                {/* Modal de Recuperação de Senha */}
                <PasswordModal open={openModalPasswd} handleClose={handleCloseModalPasswd} />
              </Paper>
            </form>
            {/* <Button
              title="Ainda não disponível"
              fullWidth
              disableElevation
              variant="outlined"
              className="my-2 bg-white-HC-dark  border-white text-[#B6CCCC] normal-case flex gap-2 w-96 font-bold"
            >
              <span >Entrar com o</span>
              <Image className="w-14 h-6" src="/govbr.svg" alt="govbr" width={10} height={10} />
            </Button> */}
            <button
              onClick={() => router.push("/sobre")}
              className="text-turquoise-HC-white-underline  outline outline-1 outline-ice-HC-white lg:text-nowrap bg-white-HC-dark  py-1 w-96 hover:bg-ice-HC-dark-hover rounded cursor-pointer"
              alt="Entrar sem cadastrar"
            >
              Entrar sem cadastrar
            </button>
            {/* <Button
              title="Ainda não disponível"
              fullWidth
              disableElevation
              variant="outlined"
              className="mt-2 bg-white-HC-dark  border-white text-[#B6CCCC] normal-case flex gap-2 w-96"
            >
              <Image className="w-6 h-6" src="/google.svg" width={10} height={10} alt="Google" />
              <span>Entrar com o Google</span>
            </Button> */}
          </div>
          <SignupModal open={openModalSignup} handleClose={handleCloseModalSignup} />
        </div>
      </div>
    </ThemeProvider >
  );
}
