import * as React from "react";
import Box from "@mui/material/Box";
import Button from "@mui/material/Button";
import Modal from "@mui/material/Modal";
import { useState } from "react";
import mecredApi from "@/axiosConfig";
import { TextField, Alert, FormControl, InputLabel, OutlinedInput, IconButton, InputAdornment } from "@mui/material";
import { removeFromLocalStorage } from "@/app/handlers/localStorageHandler";
import CloseIcon from '@mui/icons-material/Close';

export default function SignupModal({ open, handleClose }) {
  const [userName, setUserName] = useState("");
  const [userEmail, setUserEmail] = useState("");
  const [userPassword, setUserPassword] = useState("");
  const [userPasswordConfirmation, setUserPasswordConfirmation] = useState("");
  const [feedbackMessage, setfeedbackMessage] = useState("");
  const [error, setError] = useState(false);
  const [showPassword, setShowPassword] = useState(false);
  const [showPasswordConfirmation, setShowPasswordConfirmation] = useState(false);

  const handleClickShowPasswordConfirmation = () => setShowPasswordConfirmation((show) => !show);


  const handleClickShowPassword = () => setShowPassword((show) => !show);
  const handleMouseDownPassword = (event) => { event.preventDefault(); };
  const handleMouseUpPassword = (event) => { event.preventDefault(); };


  const helperText = "As senhas devem ser iguais!";

  const userSignup = async () => {
    mecredApi
      .post("/auth", {
        name: userName,
        email: userEmail,
        password: userPassword,
        password_confirmation: userPasswordConfirmation,
      })
      .then((response) => {
        setfeedbackMessage(
          "Usuário cadastrado com sucesso! Por favor confirme seu e-mail."
        );
        removeFromLocalStorage("access_token");
        setError(false);
      })
      .catch((e) => {
        setfeedbackMessage(e["response"]["data"]["errors"]["full_messages"][0]);
        setError(true);
      });
  };

  const resetForm = () => {
    setUserName("");
    setUserEmail("");
    setUserPassword("");
    setUserPasswordConfirmation("");
  };

  const handleSubmit = (event) => {
    event.preventDefault();

    if (!userName || !userEmail || !userPassword || !userPasswordConfirmation) {
      setfeedbackMessage("Todos os campos marcados com * são obrigatórios!");
      setError(true);
    } else if (userPassword != userPasswordConfirmation) {
      setfeedbackMessage("As senhas devem ser iguais!");
      setError(true);
    } else userSignup();
    resetForm();
  };

  return (
    <Modal
      className="grid h-screen place-items-center m-5"
      open={open}
      onClose={handleClose}
      slotProps={{
        backdrop: {
          sx: {
            backgroundColor: "rgba(0, 0, 0, 0.3)", // Ajuste a opacidade conforme necessário
          },
        },
      }}
    >
      <Box className="bg-white-HC-dark outline outline-1 outline-ice-HC-white sm:w-1/2 xl:w-1/4 p-5 flex flex-col items-center border-none rounded-xl">
        <div className="flex w-full">
          <h1 className="text-turquoise-HC-white text-center w-full flex-1 text-2xl font-bold m-5">Cadastre-se</h1>
          <CloseIcon onClick={handleClose} sx={{ color: "var(--darkGray-HC-white)", fontSize: "30px", marginTop: "5px" }} className="" />
        </div>

        <form onSubmit={handleSubmit} className="flex flex-col w-full">
          {feedbackMessage ? (
            <Alert className="mb-3" severity={error ? "error" : "success"}>
              {feedbackMessage}
            </Alert>
          ) : null}
          <div className="w-full mb-3">
            <label htmlFor="nome" className="block text-sm font-light text-darkGray-HC-white mb-1">
              Nome Completo *
            </label>
            <input
              id="nome"
              type="text"
              className="w-full px-3 py-2 border border-mediumGray-HC-white rounded-md focus:outline-none focus:ring-2 focus:ring-turquoise-HC-white"
              onChange={(e) => setUserName(e.target.value)}
              value={userName}
              alt="Nome Completo (obrigatório)"
            />
          </div>
          <div className="w-full mb-3">
            <label htmlFor="email" className="block text-sm font-light text-darkGray-HC-white mb-1">
              E-mail *
            </label>
            <input
              id="email"
              type="email"
              className="w-full px-3 py-2 border border-mediumGray-HC-white rounded-md focus:outline-none focus:ring-2 focus:ring-turquoise-HC-white"
              onChange={(e) => setUserEmail(e.target.value)}
              value={userEmail}
              alt="E-mail (obrigatório)"
            />
          </div>
          <div className="w-full mb-3">
            <label htmlFor="password" className="block text-sm font-light text-darkGray-HC-white mb-1">
              Senha *
            </label>
            <div className="relative">
              <input
                id="password"
                type={showPassword ? 'text' : 'password'}
                className="w-full px-3 py-2 border border-mediumGray-HC-white rounded-md focus:outline-none focus:ring-2 focus:ring-turquoise-HC-white"
                onChange={(e) => setUserPassword(e.target.value)}
                value={userPassword}
                alt="Senha (obrigatório)"
              />
              <button
                type="button"
                onClick={handleClickShowPassword}
                className="absolute inset-y-0 right-0 pr-3 flex items-center text-mediumGray-HC-dark text-sm leading-5"
              >
                {showPassword ? (
                  <img src="ocultar-senha.svg" alt="Ocultar senha" />
                ) : (
                  <img src="ver-senha.svg" alt="Ver senha" />
                )}
              </button>
            </div>
            {error && !userPassword && (
              <p className="text-red-HC-white text-sm mt-1">A senha é obrigatória.</p>
            )}
          </div>

          <div className="mb-4 ml-1">
            <p className="text-darkGray-HC-white text-sm">A senha deve ter no mínimo 8 caracteres.</p>
          </div>
          <div className="w-full mb-4">
            <label htmlFor="passwordConfirmation" className="block text-sm font-light text-darkGray-HC-white mb-1">
              Confirmar senha *
            </label>
            <div className="relative">
              <input
                id="passwordConfirmation"
                type={showPasswordConfirmation ? 'text' : 'password'}
                className="w-full px-3 py-2 border border-mediumGray-HC-white rounded-md focus:outline-none focus:ring-2 focus:ring-turquoise-HC-white"
                onChange={(e) => setUserPasswordConfirmation(e.target.value)}
                value={userPasswordConfirmation}
                alt="Confirmar senha (obrigatório)"
              />
              <button
                type="button"
                onClick={handleClickShowPasswordConfirmation}
                className="absolute inset-y-0 right-0 pr-3 flex items-center text-mediumGray-HC-dark text-sm leading-5"
              >
                {showPasswordConfirmation ? (
                  <img src="ocultar-senha.svg" alt="Ocultar senha" />
                ) : (
                  <img src="ver-senha.svg" alt="Ver senha" />
                )}
              </button>
            </div>
            {userPasswordConfirmation.length > 0 && userPasswordConfirmation !== userPassword && (
              <p className="text-red-HC-white text-sm mt-1">{helperText}</p>
            )}
          </div>
          <Button
            fullWidth
            disableElevation
            className="bg-turquoise-HC-white text-white-HC-dark-underline hover:bg-darkTurquoise-HC-dark hover:text-white font-bold py-2 rounded-md outline outline-1 outline-ice-HC-white"
            type="submit"
            alt="Enviar"
          >
            Enviar
          </Button>

          {/* <Divider flexItem className="mt-2">
            <p className="text-darkGray-HC-white-underline text-base">OU</p>
          </Divider> */}
          {/* <Button
            fullWidth
            disableElevation
            variant="outlined"
            className="mt-2 border-main text-darkGray-HC-white-underline normal-case flex gap-2"
            alt="Cadastrar-se com o Google"
          >
            <Image
              height="0"
              width="0"
              className="w-6 h-6"
              src="/google.svg"
              alt="google logo"
            />
            <span>Cadastrar-se com o Google</span>
          </Button> */}
        </form>
      </Box>
    </Modal>
  );
}
