import { Checkbox, FormGroup, Paper, TextField, Button } from "@mui/material";
import { useState, useEffect } from "react";
import FieldLabel from "./FieldLabel";
import FormControlLabel from "@mui/material/FormControlLabel";
import SubjectSelection from "./SubjectSelection";
import ObjectTypeSelection from "./ObjectTypeSelection";
import LicenseSelection from "./LicenseSelection";
import TagInput from "./TagsInput";
import AuthorSelection from "./AuthorSelection";
import mecredApi from "@/axiosConfig";
import ModalIncompleteField from "./ModalIncompleteField";
import CancelSubmitModal from "./CancelSubmitModal";
import CustomTextField from "./CustomTextField";
import CustomCheckbox from "./CustomCheckbox";


export default function InfoForm({ userData, setStep, draft, setDraft, authorType, setAuthorType }) {
  const [languagesAvailable, setLanguagesAvailable] = useState([]);
  const [scholarityLevelsAvailable, setScholarityLevelAvailable] = useState([]);
  const [openModal, setOpenModal] = useState(false);
  const [filled, setFilled] = useState(false);

  const [title, setTitle] = useState(draft?.name ?? "");
  const [description, setDescription] = useState(draft?.description ?? "");
  const [tags, setTags] = useState(draft?.tags ?? []);
  const [author, setAuthor] = useState(draft?.author ?? userData.name);
  const [tagInput, setTagInput] = useState("");
  const [languages, setLanguages] = useState(draft?.language ?? []);
  const [objectTypes, setObjectTypes] = useState(draft?.object_type_f ?? []);
  const [scholarityLevelsName, setScholarityLevelsName] = useState(draft?.educational_stages_name ?? []);
  const [subjects, setSubjects] = useState(draft?.subjects ?? []);
  const [licenseValue, setLicenseValue] = useState(draft?.license_id ?? "");

  const [languageIds, setLanguageIds] = useState(draft?.language_ids ?? []);
  const [scholarityLevelsId, setScholarityLevelsId] = useState(draft?.educational_stages ?? []);

  const [openModalCancel, setOpenModalCancel] = useState(false);



  useEffect(() => {
    mecredApi.get("/languages")
      .then((response) => { setLanguagesAvailable(response.data) });
  }, []);

  useEffect(() => {
    mecredApi.get("/educational_stages")
      .then((response) => { setScholarityLevelAvailable(response.data) });
  }, []);

  const handleTitleChange = (e) => setTitle(e.target.value);
  const handleDescriptionChange = (e) => setDescription(e.target.value);
  const handleRadioChange = (e) => {
    setAuthorType(e.target.value);
    if (e.target.value === "a")
      setAuthor(draft?.publisher?.name)

  }
  const handleAuthorChange = (e) => setAuthor(e.target.value);
  const handleLicenseValueChange = (e) => setLicenseValue(e.target.value);

  const handleKeyDown = (e) => {
    // Verifica se a tecla pressionada foi "Enter"
    if (e.key === "Enter") {
      addTagFromInput();
    }
  };
  
  const handleTagInput = (e) => {
    const value = e.target.value;
  
    // Verifica se o valor contém uma vírgula
    if (value.includes(",")) {
      addTagFromInput(value);
    } else {
      setTagInput(value);
    }
  };
  
  const addTagFromInput = (value = tagInput) => {
    // Remove a vírgula, se houver, e os espaços
    const trimmedValue = value.replace(",", "").trim();
  
    // Adiciona a tag se não estiver vazia e não for duplicada
    if (trimmedValue !== "" && !tags.includes(trimmedValue)) {
      setTags((prevTags) => [...prevTags, trimmedValue]);
    }
  
    // Limpa o campo de entrada
    setTagInput("");
  };
  

  const handleTagDelete = (tag) => {
    setTags(tags.filter((t) => t !== tag));
  };

  const handleLanguagesChange = (e) => {
    const lang = JSON.parse(e.target.value);
    if (languages.includes(lang.name)) {
      setLanguages(l => l.filter((language) => language !== lang.name));
      setLanguageIds(l => l.filter((language) => language !== lang.id));
    }
    else {
      setLanguages([...languages, lang.name])
      setLanguageIds([...languageIds, lang.id])
    };
  };

  const handleObjectsTypeChange = (subject) => {
    if (objectTypes.includes(subject))
      setObjectTypes(objectTypes.filter((object) => object.id !== subject.id));
    else setObjectTypes([subject]);
  };

  const handleScholarityChange = (e) => {
    const sl = JSON.parse(e.target.value);
    if (scholarityLevelsName.includes(sl.name)) {
      setScholarityLevelsName(s => s.filter((educational_stages) => educational_stages !== sl.name));
      setScholarityLevelsId(scholarityLevelsId.filter((educational_stages) => educational_stages !== (JSON.stringify(sl.id))));
    }
    else {
      setScholarityLevelsName([...scholarityLevelsName, sl.name]);
      setScholarityLevelsId([...scholarityLevelsId, (JSON.stringify(sl.id))]);
    }
  };

  const handleSubjectsChange = (subject) => {
    if (subjects.includes(subject))
      setSubjects(subjects.filter((subj) => subj.id !== subject.id));
    else {
      setSubjects([...subjects, subject])
    };
  };

  const handleIncompleteField = () => {
    if (!title || !description || !tags.length || !scholarityLevelsId.length || !objectTypes.length
      || !languages.length || !subjects.length || !licenseValue) {
      setFilled(true)
      return true
    }
    return false
  }



  const handleSubmit = (e) => {

    if (handleIncompleteField()) {
      e.preventDefault()
      setOpenModal(true)

    } else {

      setDraft((curr) => ({
        ...curr,
        name: title,
        description: description,
        tags: tags,
        author: author,
        object_type_f: objectTypes,
        language_ids: languageIds,
        language: languages,
        educational_stages: scholarityLevelsId,
        educational_stages_name: scholarityLevelsName,
        subjects: subjects,
        license_id: licenseValue,
      }));

      setStep((curr) => curr + 1);
    }

  }

  return (
    <>
      <form className="mb-10" onSubmit={handleSubmit} onKeyDown={(e) => { if (e.key === "Enter") e.preventDefault() }} >
        <Paper 
          className="rounded-lg p-10 max-xl:p-5 max-xl:mx-5 "  
          elevation={1}
          sx={{
            backgroundColor: 'var(--white-HC-dark)',
            border: '2px solid var(--ice-HC-white)',
            borderRadius: '8px',
          }}
        >
          <h1 className="text-darkGray-HC-white font-light text-2xl text-center">
            Os campos marcados com * são obrigatórios
          </h1>
          <FieldLabel 
            name="Título do Recurso*" 
            error={(!title && filled)}
          />
          <CustomTextField
            multiline
            fullWidth
            value={title}
            placeholder={"Ex: Jogo Virtual sobre os Biomas do Brasil"}
            onChange={handleTitleChange}
            helperText={<div className=" w-full justify-end flex">
              {title.length}/100
            </div>}
            error={(title.length > 100) || (!title && filled)}
            className="mb-5"
            sx={{
              "& .MuiOutlinedInput-input::placeholder": {
              color: "var(--darkGray-HC-white)",
              opacity: 0.5,         
            },
            }}
          />
          <FieldLabel name="Descrição geral do Recurso*" error={(!description && filled)} />
          <CustomTextField
            multiline
            rows={5}
            fullWidth
            value={description}
            placeholder={"Quais assuntos são contemplados neste recurso? Para quais objetivos este recurso pode ser destinado?"}
            onChange={handleDescriptionChange}
            helperText={<div className=" w-full justify-end flex">
              {description.length}/1500
            </div>}
            error={(description.length > 1500) || (!description && filled)}
            className="mb-5"
          />
          <FieldLabel
            name="Palavras-chave Relacionadas ao Conteúdo do seu Recurso*"
            description="(Use Enter ou vírgula para confirmar a palavra-chave)"
            error={(!tags.length && filled)}
          />
          <CustomTextField
            fullWidth
            error={(!tags.length && filled)}
            value={tagInput}
            placeholder="Ex: Bioma, Geografia"
            onChange={handleTagInput}
            onKeyUp={handleKeyDown}
            helperText={<div className=" w-full justify-end flex">
              {tagInput.length}/100
            </div>}
            className="mb-5"
          />
          <TagInput tags={tags} handleTagDelete={handleTagDelete} />
          <AuthorSelection
            selectedValue={authorType}
            handleRadioChange={handleRadioChange}
            author={author}
            handleAuthorChange={handleAuthorChange}
          />
          <ObjectTypeSelection
            error={!objectTypes.length && filled}
            selected={objectTypes}
            handleSelection={handleObjectsTypeChange}
          />
          <FieldLabel name="Idiomas do Recurso*" error={!languages.length && filled} />
          <FormGroup className="flex flex-wrap mb-10" row>
            {languagesAvailable?.map((language, index) => (
              <FormControlLabel
                onChange={handleLanguagesChange}
                key={index}
                control={<CustomCheckbox checked={languages.includes(language.name)} />}
                value={JSON.stringify(language)}
                label={<span className="text-darkGray-HC-white">{language.name}</span>}
              />
            ))}
          </FormGroup>
          <FieldLabel
            name="Nível de ensino"
            description="(Selecione uma ou mais opções)*"
            error={!scholarityLevelsId.length && filled}
          />
          <FormGroup className="flex flex-wrap mt-5 mb-10">
            {scholarityLevelsAvailable.map((sl, index) => (
              <FormControlLabel
                onChange={handleScholarityChange}
                key={index}
                control={<CustomCheckbox checked={scholarityLevelsName.includes(sl.name)} />}
                value={JSON.stringify(sl)}
                label={<span className="text-darkGray-HC-white">{sl.name}</span>}
              />
            ))}
          </FormGroup>
          <SubjectSelection
            error={!subjects.length && filled}
            selected={subjects}
            handleSelection={handleSubjectsChange}
          />
          <LicenseSelection
            error={!licenseValue && filled}
            selectedValue={licenseValue}
            handleRadioChange={handleLicenseValueChange}
          />
        </Paper>
        <h1 className="text-darkGray-HC-white font-light text-base pt-1 text-end max-xl:pr-6">
          Os campos marcados com * são de preenchimento obrigatório
        </h1>
        <div className="flex w-full justify-end p-3">

          <Button
            onClick={() => { setOpenModalCancel(true) }}
            type="button"
            variant="text"
            className="normal-case w-36 text-base text-darkGray-HC-white-underline font-bold mr-2 outline outline-1 outline-ice-HC-white hover:bg-lightGray-HC-white hover:text-darkGray-HC-dark-underline"
          >
            Cancelar
          </Button>
          <Button
            type="submit"
            className="border-turquoise-HC-white w-36 rounded-lg hover:bg-darkTurquoise-HC-dark bg-turquoise-HC-white text-base text-white-HC-dark-underline hover:text-white-HC-underline font-bold normal-case flex"
            variant="outlined"
          >
            Continuar
          </Button>
        </div>

      </form>
      <CancelSubmitModal openModal={openModalCancel} onClose={() => { setOpenModalCancel(false) }} />
      <ModalIncompleteField openModal={openModal} onClose={() => { setOpenModal(false) }} />
    </>
  );
}
