import Radio from "@mui/material/Radio";
import RadioGroup from "@mui/material/RadioGroup";
import FormControlLabel from "@mui/material/FormControlLabel";
import { licenses } from "./Licenses";
import FieldLabel from "../../components/FieldLabel";
import HelpIcon from '@mui/icons-material/Help';
import LicenseModal from "./LicenseModals";
import { useState } from "react";


export default function LicenseSelection({ handleRadioChange, selectedValue, error }) {
  const [openModalLicense, setOpenModalLicense] = useState(false)
  
  return (
    <>
      <LicenseModal openModal={openModalLicense} onClose={() => setOpenModalLicense(false)} />
      <div className="flex flex-col items-start">
        <div className="flex flex-row">
          <FieldLabel name="Licença do Uso do Conteúdo*" error={error} />
          <button type="button" onClick={() => setOpenModalLicense(true)}>
            <HelpIcon fontSize="medium" className="text-darkGray-HC-white" />
          </button>
        </div>
        <RadioGroup
          aria-labelledby="demo-radio-buttons-group-label"
          name="radio-buttons-group"
          className="mb-5"
          value={selectedValue}
          sx={{
            '& .MuiRadio-root': {
              color: 'var(--darkGray-HC-white)', // Default radio color
              '&.Mui-checked': {
                color: 'var(--turquoise-HC-white)', // Selected radio color
              },
            },
          }}
        >
          {licenses.map((license) => (
            <div key={license.id}>
              <FormControlLabel
                onChange={handleRadioChange}
                value={license.id}
                control={<Radio />}
                label={
                  <div className="align-text-center">
                    <h1 className="text-darkGray-HC-white font-bold">{license.name}</h1>
                  </div>
                }
              />
              <p className="mx-10 mb-5 text-darkGray-HC-white">{license.description}</p>
            </div>
          ))}
        </RadioGroup>
      </div>
    </>
  );
}
