import Backdrop from '@mui/material/Backdrop';
import Modal from '@mui/material/Modal';
import CloseIcon from '@mui/icons-material/Close';
import { IconButton } from '@mui/material';

/**
 * 
 * @param {object} props 
 * @param {Boolean} props.openModal
 * @param {Function} props.onClose
 * @param {Boolean} props.permission nivel de permissao do usuario, "true" para permissao de publicador
 * @returns modal de sucesso
 */
export default function ModalSuccess({ openModal, onClose, permission, idResource }) {

    const textSuccess = (permission) => {
        switch (permission) {
            case true:
                return (
                    <p>
                        Seu recurso foi publicado.
                    </p>
                )
            case false:
                return (
                    <>
                    <p>
                        Seu recurso foi submetido para que nossa equipe de curadoria possa avália-lo antes de torná-lo público.
                    </p>
                    <p className='pt-2 text-base'>
                        Em média os recursos levam 7 dias para serem homologados.
                    </p>
                    </>
                )
        }
    }

    return (

        <Modal
            className='flex justify-center items-stretch m-4'
            aria-labelledby="transition-modal-title"
            aria-describedby="transition-modal-description"
            open={openModal}
            onClose={onClose}
            closeAfterTransition
            slots={{ backdrop: Backdrop }}
            slotProps={{
                backdrop: {
                    timeout: 500,
                    backgroundColor: "rgba(0, 0, 0, 0.3)", // Ajuste a opacidade conforme necessário
                },
            }}
            
        >
            <div className='absolute p-4 pb-14 rounded-lg  self-center bg-white-HC-dark  border-2 border-ice-HC-white'>
                <>
                    <div className='flex justify-end'>
                        <IconButton onClick={onClose} className='group hover:bg-ice-HC-white'>
                            <CloseIcon 
                                fontSize='large' 
                                className='text-darkGray-HC-white group-hover:text-darkGray-HC-dark'    
                            />
                        </IconButton>
                    </div>
                    <div className='px-12'>
                        <p className='flex justify-center text-darkGray-HC-white text-2xl font-semibold pb-6 '>Sucesso!</p>
                        <p className='text-center text-darkGray-HC-white text-xl'>
                            {textSuccess(permission)}
                        </p>
                    </div>
                </>
                <div className='flex justify-center'>
                    <a className='text-white-HC-dark-underline rounded-lg p-2 mt-6 border-turquoise-HC-white hover:bg-darkTurquoise-HC-dark bg-turquoise-HC-white hover:text-white-HC-underline outline outline-1 outline-ice-HC-white' href={`/recurso/${idResource}`} >Visualizar recurso</a>
                </div>
            </div>
        </Modal>
    );
}
