"use client";
import { Button, LinearProgress } from "@mui/material";
import mecredApi from "@/axiosConfig";
import { getStoredValue } from "@/app/handlers/localStorageHandler";
import FileUploadIcon from '@mui/icons-material/FileUpload';
import { useState } from "react";
import { imageType, videoType, textType, audioType } from "@/app/components/FileTypeUtilities";
import ErrorType from "./ErrorType";
import ErrorSize from "./ErrorSize";

//const chunkSize = 262144;
const chunkSize = 1024 * 1024;

function headerConfig() {
    return {
        headers: {
            "access-token": getStoredValue("access_token"),
            "token-type": "Bearer",
            client: getStoredValue("client"),
            uid: getStoredValue("uid"),
            Expires: 0,
        }
    };
}

export default function UploadFile({ setUploading, setProgress, draft, file, setFile, attachmentId, setAttachmentId }) {
    const [open, setOpen] = useState(false);
    const [openType, setOpenType] = useState(false);

    const fileUpload = async (file) => {
        setUploading("sending");

        let numChunksToSend = Math.ceil(file.size / chunkSize);
        let start = 0;
        let response = null;

        for (let i = 0; i < numChunksToSend; i++) {
            let fileSlice = file.slice(start, Math.min(start + chunkSize, file.size));

            let formData = new FormData();
            formData.append('_chunkFilename', file.name);
            formData.append('_chunkIdentifier', draft.id + '-' + file.name);
            formData.append('_totalChunks', numChunksToSend);
            formData.append('_chunkSize', chunkSize);
            formData.append('_currentChunkSize', fileSlice.size);
            formData.append('_chunkNumber', i);
            formData.append('_totalSize', file.size);
            formData.append('file', fileSlice);
            formData.append('cancel', false);

            response = await mecredApi.post("/learning_objects/" + draft.id + "/chunk", formData, headerConfig())
                .catch((error) => console.error(error));

            // Atualiza o progresso com base nos chunks enviados
            setProgress(Math.round(((i + 1) / numChunksToSend) * 100));
            start += chunkSize;
        }

        setAttachmentId(response.data.id);
        setUploading("file");
    }

    const handleDelete = async () => {
        let url = `/learning_objects/${draft.id}/attachment/${attachmentId}`;

        await mecredApi
            .delete(url, headerConfig())
            .then(() => {
                setAttachmentId(null);
                setUploading("nothing");
                setFile(null);
                setProgress(0); // Reset progress
            })
            .catch((error) => console.error(error));
    }

    const onFileChange = (e) => {
        e.preventDefault();
        const fileInput = e.target?.files[0];

        if (!fileInput) return;

        if (fileInput.size >= 2e8) {
            setOpen(true);
            e.target.value = null;
            return;
        }

        if (
            !imageType(fileInput.type) &&
            !audioType(fileInput.type) &&
            !videoType(fileInput.type) &&
            !textType(fileInput.type)
        ) {
            setOpenType(true);
            e.target.value = null;
            return;
        }

        setFile(fileInput);
        fileUpload(fileInput);
    }

    return (
        <div id="form-file" className="flex flex-col w-full min-h-72 items-center justify-around">
            <ErrorSize open={open} handleClose={() => setOpen(false)} />
            <ErrorType open={openType} handleClose={() => setOpenType(false)} />
            <div className={`flex h-24 w-24 my-5 mx-10 rounded-full items-center justify-center bg-ice-HC-white`}>
                <FileUploadIcon fontSize="large" className="text-darkGray-HC-dark" />
            </div>

            {!attachmentId ? (
                <>
                    <h1 className="text-center text-2xl text-darkGray-HC-white">
                        Envie o arquivo do recurso
                    </h1>
                    <p className="text-center text-sm text-darkGray-HC-white">
                        O arquivo pode ter o tamanho máximo de 200MB.
                    </p>
                    <Button
                        variant="outlined"
                        component="label"
                        className="text-white-HC-dark-underline font-bold px-10 rounded-lg w-64 hover:text-white-HC-underline bg-turquoise-HC-white hover:bg-darkTurquoise-HC-dark border-1 border-transparent hover:border-darkTurquoise-HC-white"
                    >
                        SELECIONAR ARQUIVO
                        <input type="file" hidden onChange={onFileChange} />
                    </Button>
                </>
            ) : (
                <>
                    <div className="flex flex-col w-full items-center">
                        <h1 className="text-center text-2xl text-darkGray-HC-white pb-4">
                            Arquivo enviado com sucesso!
                        </h1>
                        <div>
                            <h2 className="text-lg text-darkGray-HC-white">Informações do arquivo enviado:</h2>
                            <h1 className="pl-4 text-darkGray-HC-white">Nome do arquivo: {file.name} <br /> Tipo do arquivo: {file.type}</h1>
                        </div>
                        <div className="flex pb-8 pt-4">
                            <Button
                                className="text-white-HC-dark-underline rounded-lg hover:text-white-HC-underline bg-turquoise-HC-white hover:bg-darkTurquoise-HC-dark border-1 border-transparent hover:border-turquoise-HC-white"
                                variant="outlined"
                                onClick={handleDelete}
                            >
                                Excluir arquivo
                            </Button>
                        </div>
                    </div>
                </>
            )}
        </div>
    );
}
