import {
  Paper, Button

} from "@mui/material";
import SubmitLink from "./SubmitLink";
import { Divider } from "@mui/material";
import FieldLabel from "./FieldLabel";
import UploadFile from "./UploadFile";
import { useState } from "react";
import SubmitThumbnail from "./SubmitThumbnail";
import mecredApi from "@/axiosConfig";
import { getStoredValue } from "@/app/handlers/localStorageHandler";
import ModalIncompleteField from "./ModalIncompleteField";
import CancelSubmitModal from "./CancelSubmitModal";
import HelpIcon from '@mui/icons-material/Help';
import Tooltip, { tooltipClasses } from '@mui/material/Tooltip';
import { styled } from '@mui/material/styles';
import { LinearProgress } from "@mui/material";




function headerConfig() {
  return {
    headers: {
      "access-token": getStoredValue("access_token"),
      "token-type": "Bearer",
      client: getStoredValue("client"),
      uid: getStoredValue("uid"),
      Expires: 0,
    }
  };
}

const CustomWidthTooltip = styled(({ className, ...props }) => (
  <Tooltip {...props} classes={{ popper: className }} />
))({
  [`& .${tooltipClasses.tooltip}`]: {
    maxWidth: 550,
    backgroundColor: " var(--lightGray-HC-dark)"
  },
});

const longText = () => {
  return (
    <p className='px-4 pt-2 text-start text-lg text-darkGray-HC-white p-4 border-2 border-lightGray-HC-white'>
      Os tipos de arquivos suportados são:

      <li className='text-sm'> Vídeos: mp4, mpeg, ogg, webm, 3gpp </li>
      <li className='text-sm'> Áudio: wav, x-wav, webm, ogg, flac, mpeg, mp3, x-mp3, mp4, aac, x-m4a </li>
      <li className='text-sm'> Image: jpeg, webp, gif, png, apng, svg+xml, bmp </li>
      <li className='text-sm'> Textos: pdf, txt, md, csv </li>
    </p>
  )
};


export default function UploadForm({ thumbURL, thumb, setThumb, setThumbURL, setStep, draft, setDraft, file, setFile, attachmentId, setAttachmentId }) {
  const [uploading, setUploading] = useState(draft.link ? "link" : file ? "file" : "nothing")
  const [filled, setFilled] = useState(false)
  const [openModal, setOpenModal] = useState(false)
  const [openModalCancel, setOpenModalCancel] = useState(false)
  const [progress, setProgress] = useState(0); // Estado para a barra de progresso


  const submitThumb = async () => {
    let finalThumb = new FormData()
    finalThumb.set('learning_object[thumbnail]', thumb);

    await mecredApi
      .put(`/learning_objects/${draft.id}`, finalThumb, headerConfig())
      .catch((error) => { console.error(error) })

  }

  const handleIncompleteField = () => {
    if (!draft.link && !file || !thumb) {
      setFilled(true)
      return true
    }
    return false
  }

  const handleSubmitUpload = () => {
    if (handleIncompleteField()) {
      setOpenModal(true)

    } else {

      submitThumb();
      setDraft((curr) => ({
        ...curr,
        attachmentID: (JSON.stringify(attachmentId)),
        file: file?.name,
      }))
      setStep(curr => curr + 1);
    }

  }


  function linkOrFileUpload(uploading, setUploading, attachmentId, file, link) {

    switch (uploading) {
      case "nothing":
        return (
          draft.object_type_f[0].name !== "Website Externo" ?
            <>
              <div className="pb-10">
                <UploadFile setUploading={setUploading} setProgress={setProgress} draft={draft} setDraft={setDraft} file={file} setFile={setFile} attachmentId={attachmentId} setAttachmentId={setAttachmentId} />
              </div>
            </>

            :
            <>
              <SubmitLink setUploading={setUploading} setDraft={setDraft} draft={draft} />
            </>
        )
      case "sending":
        return (
          <>
            <p className="text-center text-xl text-darkGray-HC-white-underline pb-10"> Aguarde um segundo! Estamos fazendo o upload do seu recurso!</p>
            {progress > 0 && <LinearProgress variant="determinate" value={progress} sx={{ height: 20 }} className="w-full mt-4 mb-4" />}
          </>

        )
      case "file":
        return (
          <UploadFile setUploading={setUploading} setProgress={setProgress} draft={draft} setDraft={setDraft} file={file} setFile={setFile} attachmentId={attachmentId} setAttachmentId={setAttachmentId} />
        )
      case "link":
        return (
          <SubmitLink setUploading={setUploading} setDraft={setDraft} draft={draft} />
        )
    }
  }

  return (
    <>
      <form className="mb-10" onKeyDown={(e) => { if (e.key === "Enter") e.preventDefault() }}>
        <Paper 
          className="rounded-lg px-10 py-1 max-xl:mx-5" 
          elevation={1}
          sx={{
            backgroundColor: 'var(--white-HC-dark)',
            border: '2px solid var(--ice-HC-white)',
          }}
        >
          <div className="flex w-full justify-between">
              <FieldLabel
                name="Enviar Recurso*"
                description={
                  draft.object_type_f[0].name !== "Website Externo" ? "Envie um arquivo" : "Envie um link externo"
                }
                error={(filled && !draft.link) && (filled && !file)}
              />
            <div className="mt-10 pl-8">
              <CustomWidthTooltip title={longText()} >
                <HelpIcon fontSize="large" className="text-turquoise-HC-white " />
              </CustomWidthTooltip>

            </div>
          </div>

          {linkOrFileUpload(uploading, setUploading, attachmentId, file, draft.link)}

          <Divider />
          <SubmitThumbnail error={filled && !thumbURL} setThumb={setThumb} thumbURL={thumbURL} setThumbURL={setThumbURL} draft={draft} setDraft={setDraft} />

        </Paper>
        <h1 className="text-darkGray-HC-white font-light text-base pt-1 text-end max-xl:pr-6">
          
        </h1>
        <div className="flex w-full justify-end p-3">
          <Button
            onClick={() => setOpenModalCancel(true)}
            type="button"
            variant="text"
            className="normal-case w-36 text-base text-darkGray-HC-white-underline font-bold mr-2 outline outline-1 outline-ice-HC-white bg-ice-HC-dark hover:bg-lightGray-HC-white hover:text-darkGray-HC-dark-underline"
          >
            Cancelar
          </Button>
          <Button
            variant="text"
            className="normal-case w-36 text-base text-darkGray-HC-white-underline font-bold mr-2 outline outline-1 outline-ice-HC-white bg-ice-HC-dark hover:bg-lightGray-HC-white hover:text-darkGray-HC-dark-underline"
            onClick={() => {
              setDraft((curr) => ({
                ...curr,
                attachmentID: (JSON.stringify(attachmentId)),
                file: file?.name,
              }))
              setStep(curr => curr - 1)
            }
            }
          >
            Voltar
          </Button>
          <Button
            className=" w-36 rounded-lg border-turquoise-HC-white hover:bg-darkTurquoise-HC-dark bg-turquoise-HC-white text-base text-white-HC-dark-underline hover:text-white-HC-underline font-bold normal-case flex"
            variant="outlined"
            onClick={handleSubmitUpload}
          >
            Continuar
          </Button>
        </div>
      </form >
      <CancelSubmitModal openModal={openModalCancel} onClose={() => setOpenModalCancel(false)} />
      <ModalIncompleteField openModal={openModal} onClose={() => { setOpenModal(false) }} />
    </>

  );
}
