"use client"
import { useEffect, useState } from "react";
import { useRouter, useSearchParams } from "next/navigation";
import { Card } from "@mui/material"
import Overlay from "../components/Overlay"
import { ImArrowLeft } from "react-icons/im";

export default function HelpTopics() {
  const router = useRouter();
  const searchParams = useSearchParams();

  const teste = [
    {
      title: "Publicando Recursos",
      questions: [
        {
          question: "Por que enviar um recurso?",
          answer: [
            "Ao enviar um recurso você estará ajudando a fortalecer a distribuição de recursos educacionais digitais para o ensino básico brasileiro e contribuindo na valorização da pluralidade e da diversidade da educação brasileira.",
            "A MEC RED é um meio seguro e um site de referência para a publicação e disseminação de Recursos Educacionais Digitais. Aproveite esse espaço para compartilhar com professores de todo o Brasil recursos criados por você ou aquele recurso de outro autor que você usou em aula e seus alunos gostaram!",
            "A partir do momento que seu recurso estiver publicado na MEC RED, os usuários poderão interagir com seu recurso e você receberá as notificações dos comentários, avaliações e curtidas. Cada uma dessas interações contam para que seu recurso ganhe uma posição de destaque na MEC RED.",
            "Participe dessa rede de colaboração de fomento da qualidade da educação básica!"
          ],
        },
        {
          question: "Como publicar um recurso?",
          answer: [
            "Você possui um material pedagógico interessante e gostaria de compartilhar com outros professores? Aproveite o espaço da MEC RED para publicar esse Recurso! Para isso, siga os passos a seguir:",
            "1. Acesse a Página Inicial da MEC RED.",
            "2. Clique no botão “Publicar Recurso” localizado no topo da página.",
            "3. No quadro pontilhado em azul (enviar recurso), no canto esquerdo da página, você pode escolher o arquivo do seu computador, arrastá-lo ao quadro ou até mesmo enviar o link de um recurso no botão “enviar link” logo abaixo.",
            "4. Em seguida, preencha as informações sobre o recurso no formulário ao lado.",
            "Dica: para que outros usuários encontre o seu recurso é muito importante que você preencha o formulário com a maior quantidade de detalhes possível! No final do formulário é só clicar no botão “Salvar e Avançar” para prosseguir ao próximo passo.",
            "Ao concluir todas as etapas, você receberá uma mensagem de confirmação do envio do seu Recurso!"
          ],
        },
        {
          question: "Quais tipos de recursos e formatos de arquivo a MEC RED aceita?",
          answer: [
            "Veja abaixo a lista dos Tipos de Recursos e alguns exemplos de Formatos de Arquivos que são aceitos para publicação na MEC RED:",
            "Imagem - JPG, WEBP, PDF e PNG",
            "Mapa - JPG, WEBP, PDF e PNG",
            "Texto - PDF, TXT, DOC e DOCX (Word)",
            "Áudio - MP3 e WAV",
            "Vídeo - WMV, MP4 e YouTube (embedado)",
            "Apresentação - PDF, PPT e PPTX (PowerPoint)",
            "Infográfico - PDF, JPG, WEBP e PNG"
          ],
        },
      ],
    },

    {
      title: "Encontrando Recursos",
      questions: [
        {
          question: "Como fazer uma busca?",
          answer: [
            "Siga os passos a seguir:",
            "1. Digite o que você procura na caixa de busca localizada no centro da página. Por exemplo: “vídeo aquecimento global” ou “aritmética”.",
            "2. No resultado serão apresentados os cartões de recursos relacionados à sua busca."
          ]
        },
        {
          question: "Como filtrar os resultados?",
          answer: [
            "Após efetuar sua busca, você pode filtrar os resultados de acordo com o que procura, com a opção “Filtros” localizada no lado esquerdo da página.",
            "Você pode filtrar pelo tipo de recurso, componentes curriculares e níveis de ensino.",
          ]
        },
        {
          question: "Como os recursos são ranqueados?",
          answer: [
            "O ranqueamento dos recursos está relacionado com as avaliações, estrelas, comentários, curtidas e até mesmo com as informações sobre o seu recurso. Ou seja, quanto mais interações positivas um recurso tiver, mais significativo ele será para a MEC RED e seus usuários. Isso quer dizer que os recursos melhores ranqueados ganham mais destaque nos resultados de busca!"
          ]
        }
      ],
    },

    {
      title: "Participando da Rede",
      questions: [
        {
          question: "Como comentar ou avaliar um recurso?",
          answer: [
            "Ao abrir um recurso, você pode avaliá-lo e descrever como foi sua experiência:",
            "1. Abra o recurso desejado.",
            "2. No fim da página haverá uma área de Relatos de Experiência.",
            "3. Preencha as informações no quadro “Conte sua experiência”.",
            "4. Clique em “Enviar”.",
            "Obs: as estrelinhas indicam se o recurso foi útil para você, então quanto mais estrelinhas, melhor será a avaliação do recurso.",
          ],
        },
        {
          question: "Que tipo de comentário posso fazer sobre o recurso?",
          answer: [
            "Aqui na MEC RED, incentivamos os usuários a comentarem os recursos contando como foi sua experiência de uso. Veja sugestões de pontos a serem abordados no seu comentário:",
            "Relatar como utilizou o recurso durante a aula, para que outros professores possam se basear e adaptar para o seu próprio objetivo pedagógico.",
            "Relatar a recepção dos alunos em relação ao recurso.",
            "Apontar os pontos a serem melhorados no recurso para que o autor tenha a oportunidade de ajustar.",
            "Apontar os pontos positivos do recurso para que o autor ganhe o devido reconhecimento e prestígio!",
          ],
        }
      ],
    },

    {
      title: "Gerenciando a Conta",
      questions: [
        {
          question: "Por que se cadastrar?",
          answer: [
            "Quais vantagens eu terei após criar um perfil na MEC RED?",
            "Ao se cadastrar, você terá mais opções de interação na MEC RED, como criar suas próprias coleções de recursos, seguir usuários e coleções de outros usuários. Além disso, poderá contribuir com a rede de usuários fazendo relatos de experiências sobre o uso dos recursos, avaliando com estrelas, favoritando e reportando violações de recursos (quando necessário)."
          ]
        },
        {
          question: "Como fazer meu cadastro?",
          answer: [
            "Para fazer o cadastro é rapidinho:",
            "1. Acesse a Página Inicial.",
            "2. Clique em “Cadastre-se” no canto superior direito da página.",
            "3. Preencha os campos solicitados.",
            "4. Clique em “Cadastrar”.",
            "Pronto! Você será conectado automaticamente.",
            "Nas próximas vezes que acessar a MEC RED, clique em “Entrar” e faça o login com seus dados de cadastro.",
          ]
        },
        {
          question: "Como alterar minha senha?",
          answer: [
            "Para alterar sua senha você precisa estar conectado na MEC RED e então, seguir esses passos:",
            "1. Na Página Inicial, clique no menu “Minha área” localizado no canto superior direito da página.",
            "2. Clique na opção “Configurações” que aparecerá no submenu.",
            "3. Clique no link “Gerenciar conta”, no menu lateral, localizado no canto superior esquerdo",
            "4. Na opção “Alterar senha”, preencha os campos com sua senha atual e depois com a nova senha que deseja.",
            "5. Clique na opção “Alterar senha” logo abaixo.",
            "Pronto! No próximo acesso, você já pode usar sua nova senha!"
          ]
        },
        {
          question: "Como acessar minha conta?",
          answer: [
            "Para acessar a sua conta:",
            "1. Acesse a Página Inicial.",
            "2. Clique em “Entrar” no canto superior direito.",
            "3. Preencha os campos solicitados.",
            "4. Clique em “Entrar”.",
          ]
        },
        {
          question: "Esqueci minha senha. O que fazer?",
          answer: [
            "Para redefinir a senha da sua conta, siga essas instruções:",
            "1. Acesse a Página Inicial e clique em “Entrar” no canto superior direito da página.",
            "2. Clique em “Esqueceu a senha? Clique Aqui!”.",
            "3. Preencha com o seu endereço de e-mail e clique em “Buscar”.",
            "4. Você receberá um e-mail no endereço informado, contendo as instruções para redefinir sua senha.",
          ]
        }
      ],
    }
  ];


  const pos = searchParams.get('pos');
  const section = searchParams.get('section')

  const [questionChosen, setQuestionChosen] = useState(teste[section]?.questions?.[pos]?.question || '');

  const [answerChosen, setAnswerChosen] = useState(teste[section]?.questions?.[pos]?.answer || '')

  function changeQuestion(itemQuestion) {
    setQuestionChosen(itemQuestion.question)
    setAnswerChosen(itemQuestion.answer)
  }

  return (
    <Overlay type="twoColumns">
      <div className="flex flex-col overflow-y-auto scrollbar-none mb-5 max-xl:ml-6 max-md:ml-0 items-center">
        <p className="text-center text-2xl font-bold text-darkGray-HC-white mb-5 2xl:hidden">Tópicos de ajuda</p>
        <div className="flex flex-row max-xl:flex-col">
          <Card
            className="bg-white-HC-dark  outline outline-1 outline-ice-HC-white 2xl:w-[400px] h-[740px] xl:w-[300px] p-[20px]  max-xl:hidden"
            sx={{
              display: "flex",
              flexDirection: "column",
              alignItems: "center",
              justifyContent: "flex-start",
              backgroundColor: "#FFFFFF",
              boxShadow: "none",
            }}
          >
            <div className="flex flex-col overflow-y-auto scrollbar-none mt-3 ml-8 mr-4 text-darkGray-HC-white gap-5 max-xl:hidden">
              <p className="mt-5 text-2xl font-bold flex text-center">Tópicos de Ajuda</p>

              {teste?.map((item, index) => (
                <div key={index}>
                  <p className="mt-5 text-lg font-bold flex text-center">{item.title}</p>
                  <div className="flex flex-col gap-2 mt-2">
                    {item?.questions?.map((questionItem, ind) => (
                      <button
                        onClick={() => changeQuestion(questionItem)}
                        className={`text-sm text-left ${questionItem.question === questionChosen ? 'bg-ice-HC-dark-hover font-bold rounded-sm p-1' : ''}`}
                        key={ind}
                      >
                        {questionItem.question}
                      </button>
                    ))}
                  </div>
                </div>
              ))}
            </div>
          </Card>
          <Card
            className="bg-white-HC-dark  outline outline-1 outline-ice-HC-white justify-start p-[30px] max-xl:p-[10px] max-lg:mx-[20px] w-[900px] max-lg:w-auto max-xl:h-auto "
            sx={{
              display: "flex",
              flexDirection: "column",
              height: 740,
              backgroundColor: "#FFFFFF",
              boxShadow: "none",
            }}
          >
            <div className="flex justify-start flex-col text-darkGray-HC-white gap-7 mt-3 mr-16 max-xl:m-5 max-xl:mb-0 max-xl:mt-0">
              <p className="mt-5 text-2xl font-bold mb-5">{questionChosen}</p>
              <div className="text-xl text-darkGray-HC-white font-light mb-5 leading-6">
                {answerChosen?.map((line, index) => (
                  <p key={index}>{line}<br /><br /></p>
                ))}
              </div>
            </div>
            <button onClick={() => router.push("/ajuda")} className="flex pl-5 pb-2 text-darkGray-HC-white font-bold 2xl:hidden">Voltar</button>
          </Card>
        </div>
        <div className="flex flex-col items-center rounded-xl px-10 max-sm:px-0  max-sm:py-6 mx-20 max-sm:mx-4 max-md:mb-16">
          <div className="text-darkGray-HC-white-underline mt-5 max-sm:mt-0 text-xl font-bold text-center">Não encontrou o que precisa?</div>
          <div className="text-darkGray-HC-white-underline text-md mt-4 ml-3 text-center">Entre em contato com nossa equipe</div>
          <button onClick={() => router.push("/contato")} className="mt-4 bg-turquoise text-lg text-white-HC-dark-underline p-2 px-4 rounded-lg hover:bg-turquoise-hover">Página de contato</button>
        </div>
      </div>

    </Overlay>
  )
}