/** @type {import('tailwindcss').Config} */
const plugin = require('tailwindcss/plugin');
const tailwindScrollbar = require('tailwind-scrollbar');
module.exports = {
  important: true,
  content: [
    "./src/pages/**/*.{js,ts,jsx,tsx,mdx}",
    "./src/components/**/*.{js,ts,jsx,tsx,mdx}",
    "./src/app/**/*.{js,ts,jsx,tsx,mdx}",
  ],
  theme: {
    extend: {
      fontSize: {
        "xs": ['var(--font-size-xs)', 'var(--line-height-xs)'],
        "sm": ['var(--font-size-sm)', 'var(--line-height-sm)'],
        "base": ['var(--font-size-base)', 'var(--line-height-base)'],
        "lg": ['var(--font-size-lg)', 'var(--line-height-lg)'],
        "xl": ['var(--font-size-xl)', 'var(--line-height-xl)'],
        "2xl": ['var(--font-size-2xl)', 'var(--line-height-2xl)'],
        "3xl": ['var(--font-size-3xl)', 'var(--line-height-3xl)'],
        "4xl": ['var(--font-size-4xl)', 'var(--line-height-4xl)'],
        "5xl": ['var(--font-size-5xl)', 'var(--line-height-5xl)'],
        "6xl": ['var(--font-size-6xl)', 'var(--line-height-6xl)'],
        "7xl": ['var(--font-size-7xl)', 'var(--line-height-7xl)'],
        "8xl": ['var(--font-size-8xl)', 'var(--line-height-8xl)'],
        "9xl": ['var(--font-size-9xl)', 'var(--line-height-9xl)'],
      },
      colors: { 
        "ice": 'var(--ice)',
        "ice-HC-dark": 'var(--ice-HC-dark)', // "#f5f9f9",
        "ice-HC-white": 'var(--ice-HC-white)',
        "ice-HC-gray": 'var(--ice-HC-gray)',
        "turquoise": 'var(--turquoise)',
        "turquoise-HC-white-underline": 'var(--turquoise-HC-white-underline)',
        "turquoise-HC-white": 'var(--turquoise-HC-white)',
        "turquoise-HC-underline": 'var(--turquoise-HC-underline)',
        "turquoise-HC-dark-underline": 'var(--turquoise-HC-dark-underline)',
        "turquoise-HC-dark": 'var(--turquoise-HC-dark)',
        "darkTurquoise-HC-gray": 'var(--darkTurquoise-HC-gray)',
        "darkTurquoise-HC-white": 'var(--darkTurquoise-HC-white)',
        "darkTurquoise-HC-dark": 'var(--darkTurquoise-HC-dark)',
        "white": 'var(--white)',
        "white-HC-underline": 'var(--white-HC-underline)',
        "white-HC-dark": 'var(--white-HC-dark)',
        "white-HC-dark-underline": 'var(--white-HC-dark-underline)',
        "orange": 'var(--orange)',
        "darkOrange-HC-gray": 'var(--darkOrange-HC-gray)',
        "darkOrange-HC-dark": 'var(--darkOrange-HC-dark)',
        "darkOrange-HC-white": 'var(--darkOrange-HC-white)',
        "darkGray-HC-dark": 'var(--darkGray-HC-dark)',
        "darkGray-HC-white": 'var(--darkGray-HC-white)',
        "darkGray-HC-white-underline": 'var(--darkGray-HC-white-underline)',
        "darkGray-HC-dark-underline": 'var(--darkGray-HC-dark-underline)',
        "black": 'var(--black)',
        "black-HC-gray": 'var(--black-HC-gray)',
        "black-HC-white": 'var(--black-HC-white)',
        "black-HC-white-underline": 'var(--black-HC-white-underline)',
        "violet": 'var(--violet)',
        "orange-HC-white": 'var(--orange-HC-white)',
        "violet-HC-white": 'var(--violet-HC-white)',
        "pink-HC-white": 'var(--pink-HC-white)',
        "darkViolet-HC-gray": 'var(--darkViolet-HC-gray)',
        "pink": 'var(--pink)',
        "darkPink-HC-gray": 'var(--darkPink-HC-gray)',
        "lightGray": 'var(--lightGray)',
        "lightGray-HC-dark": 'var(--lightGray-HC-dark)',
        "lightGray-HC-white": 'var(--lightGray-HC-white)',
        "lightGray-HC-white-underline": 'var(--lightGray-HC-white-underline)',
        "lightGray-HC-dark-underline": 'var(--lightGray-HC-dark-underline)',
        "red-HC-white": 'var(--red-HC-white)',
        "mediumGray-HC-white": 'var(--mediumGray-HC-white)',
        "mediumGray-HC-dark": 'var(--mediumGray-HC-dark)',
        "lightGray-HC-dark": 'var(--lightGray-HC-dark)',        
      },
      backgroundImage: {
        "gradient-radial": "radial-gradient(var(--tw-gradient-stops))",
        "gradient-conic":
        "conic-gradient(from 180deg at 50% 50%, var(--tw-gradient-stops))",
        "fundo": 'var(--fundo)',
        "logo": 'var(--logo)',
        "logo-square": 'var(--logo-square)',
      },
      keyframes: {
        scrollHint: {
          '0%, 100%': { transform: 'translateX(0)' },
          '50%': { transform: 'translateX(-20px)' },
        },
      },
      animation: {
        scrollHint: 'scrollHint 0.5s ease-in-out 1 ',
      },
      height:{
       'nav-bar': 'var(--nav-bar)'
      }
    },
  },


  plugins: [
    function ({ addUtilities }) {
      const newUtilities = {
        '.text-main-text': {
          'text-decoration': 'var(--underline)',
        },
        '.text-white-HC-dark-underline': {
          'text-decoration': 'var(--underline)',
        },
        '.text-white-HC-underline': {
          'text-decoration': 'var(--underline)',
        },
        '.text-darkGray-HC-white-underline': {
          'text-decoration': 'var(--underline)',
        },
        '.text-darkGray-HC-dark-underline': {
          'text-decoration': 'var(--underline)',
        },
        '.text-turquoise-HC-underline': {
          'text-decoration': 'var(--underline)',
        },
        '.text-darkGray-HC-white-underline': {
          'text-decoration': 'var(--underline)',
        },
        '.text-turquoise-HC-underline': {
          'text-decoration': 'var(--underline)',
        },
        '.invertIcon-HC-black': { /* Icones pretos => branco */
          'filter': 'var(--invert)',
        },
        '.text-turquoise-HC-white-underline': {
          'text-decoration': 'var(--underline)',
        },
        '.text-turquoise-HC-dark-underline': {
          'text-decoration': 'var(--underline)',
        },
        '.text-black-HC-white-underline': {
          'text-decoration': 'var(--underline)',
        },
        '.text-lightGray-HC-white-underline': {
          'text-decoration': 'var(--underline)',
        },
        '.text-lightGray-HC-dark-underline': {
          'text-decoration': 'var(--underline)',
        },
        '.invertLogo-HC-white': {
          'filter': 'var(--filter)'
        }
      };

      addUtilities(newUtilities, ['responsive', 'hover']);
    },
    tailwindScrollbar, // Adicionando o plugin de scrollbar
  ],
};
